==> zio-aws-iot_2.12-5.17.191.2-sources.jar: zio/aws/iot/model/ViolationEvent.scala <==
package zio.aws.iot.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iot.model.primitives.{
  DeviceDefenderThingName,
  ViolationId,
  Timestamp,
  SecurityProfileName,
  VerificationStateDescription
}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class ViolationEvent(
    violationId: Optional[ViolationId] = Optional.Absent,
    thingName: Optional[DeviceDefenderThingName] = Optional.Absent,
    securityProfileName: Optional[SecurityProfileName] = Optional.Absent,
    behavior: Optional[zio.aws.iot.model.Behavior] = Optional.Absent,
    metricValue: Optional[zio.aws.iot.model.MetricValue] = Optional.Absent,
    violationEventAdditionalInfo: Optional[
      zio.aws.iot.model.ViolationEventAdditionalInfo
    ] = Optional.Absent,
    violationEventType: Optional[zio.aws.iot.model.ViolationEventType] =
      Optional.Absent,
    verificationState: Optional[zio.aws.iot.model.VerificationState] =
      Optional.Absent,
    verificationStateDescription: Optional[VerificationStateDescription] =
      Optional.Absent,
    violationEventTime: Optional[Timestamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.ViolationEvent = {
    import ViolationEvent.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.ViolationEvent
      .builder()
      .optionallyWith(
        violationId.map(value => ViolationId.unwrap(value): java.lang.String)
      )(_.violationId)
      .optionallyWith(
        thingName.map(value =>
          DeviceDefenderThingName.unwrap(value): java.lang.String
        )
      )(_.thingName)
      .optionallyWith(
        securityProfileName.map(value =>
          SecurityProfileName.unwrap(value): java.lang.String
        )
      )(_.securityProfileName)
      .optionallyWith(behavior.map(value => value.buildAwsValue()))(_.behavior)
      .optionallyWith(metricValue.map(value => value.buildAwsValue()))(
        _.metricValue
      )
      .optionallyWith(
        violationEventAdditionalInfo.map(value => value.buildAwsValue())
      )(_.violationEventAdditionalInfo)
      .optionallyWith(violationEventType.map(value => value.unwrap))(
        _.violationEventType
      )
      .optionallyWith(verificationState.map(value => value.unwrap))(
        _.verificationState
      )
      .optionallyWith(
        verificationStateDescription.map(value =>
          VerificationStateDescription.unwrap(value): java.lang.String
        )
      )(_.verificationStateDescription)
      .optionallyWith(
        violationEventTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.violationEventTime)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.ViolationEvent.ReadOnly =
    zio.aws.iot.model.ViolationEvent.wrap(buildAwsValue())
}
object ViolationEvent {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.ViolationEvent
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.ViolationEvent =
      zio.aws.iot.model.ViolationEvent(
        violationId.map(value => value),
        thingName.map(value => value),
        securityProfileName.map(value => value),
        behavior.map(value => value.asEditable),
        metricValue.map(value => value.asEditable),
        violationEventAdditionalInfo.map(value => value.asEditable),
        violationEventType.map(value => value),
        verificationState.map(value => value),
        verificationStateDescription.map(value => value),
        violationEventTime.map(value => value)
      )
    def violationId: Optional[ViolationId]
    def thingName: Optional[DeviceDefenderThingName]
    def securityProfileName: Optional[SecurityProfileName]
    def behavior: Optional[zio.aws.iot.model.Behavior.ReadOnly]
    def metricValue: Optional[zio.aws.iot.model.MetricValue.ReadOnly]
    def violationEventAdditionalInfo
        : Optional[zio.aws.iot.model.ViolationEventAdditionalInfo.ReadOnly]
    def violationEventType: Optional[zio.aws.iot.model.ViolationEventType]
    def verificationState: Optional[zio.aws.iot.model.VerificationState]
    def verificationStateDescription: Optional[VerificationStateDescription]
    def violationEventTime: Optional[Timestamp]
    def getViolationId: ZIO[Any, AwsError, ViolationId] =
      AwsError.unwrapOptionField("violationId", violationId)
    def getThingName: ZIO[Any, AwsError, DeviceDefenderThingName] =
      AwsError.unwrapOptionField("thingName", thingName)
    def getSecurityProfileName: ZIO[Any, AwsError, SecurityProfileName] =
      AwsError.unwrapOptionField("securityProfileName", securityProfileName)
    def getBehavior: ZIO[Any, AwsError, zio.aws.iot.model.Behavior.ReadOnly] =
      AwsError.unwrapOptionField("behavior", behavior)
    def getMetricValue
        : ZIO[Any, AwsError, zio.aws.iot.model.MetricValue.ReadOnly] =
      AwsError.unwrapOptionField("metricValue", metricValue)
    def getViolationEventAdditionalInfo: ZIO[
      Any,
      AwsError,
      zio.aws.iot.model.ViolationEventAdditionalInfo.ReadOnly
    ] = AwsError.unwrapOptionField(
      "violationEventAdditionalInfo",
      violationEventAdditionalInfo
    )
    def getViolationEventType
        : ZIO[Any, AwsError, zio.aws.iot.model.ViolationEventType] =
      AwsError.unwrapOptionField("violationEventType", violationEventType)
    def getVerificationState
        : ZIO[Any, AwsError, zio.aws.iot.model.VerificationState] =
      AwsError.unwrapOptionField("verificationState", verificationState)
    def getVerificationStateDescription
        : ZIO[Any, AwsError, VerificationStateDescription] =
      AwsError.unwrapOptionField(
        "verificationStateDescription",
        verificationStateDescription
      )
    def getViolationEventTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("violationEventTime", violationEventTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.ViolationEvent
  ) extends zio.aws.iot.model.ViolationEvent.ReadOnly {
    override val violationId: Optional[ViolationId] = zio.aws.core.internal
      .optionalFromNullable(impl.violationId())
      .map(value => zio.aws.iot.model.primitives.ViolationId(value))
    override val thingName: Optional[DeviceDefenderThingName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.thingName())
        .map(value =>
          zio.aws.iot.model.primitives.DeviceDefenderThingName(value)
        )
    override val securityProfileName: Optional[SecurityProfileName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.securityProfileName())
        .map(value => zio.aws.iot.model.primitives.SecurityProfileName(value))
    override val behavior: Optional[zio.aws.iot.model.Behavior.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.behavior())
        .map(value => zio.aws.iot.model.Behavior.wrap(value))
    override val metricValue: Optional[zio.aws.iot.model.MetricValue.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.metricValue())
        .map(value => zio.aws.iot.model.MetricValue.wrap(value))
    override val violationEventAdditionalInfo
        : Optional[zio.aws.iot.model.ViolationEventAdditionalInfo.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.violationEventAdditionalInfo())
        .map(value =>
          zio.aws.iot.model.ViolationEventAdditionalInfo.wrap(value)
        )
    override val violationEventType
        : Optional[zio.aws.iot.model.ViolationEventType] = zio.aws.core.internal
      .optionalFromNullable(impl.violationEventType())
      .map(value => zio.aws.iot.model.ViolationEventType.wrap(value))
    override val verificationState
        : Optional[zio.aws.iot.model.VerificationState] = zio.aws.core.internal
      .optionalFromNullable(impl.verificationState())
      .map(value => zio.aws.iot.model.VerificationState.wrap(value))
    override val verificationStateDescription
        : Optional[VerificationStateDescription] = zio.aws.core.internal
      .optionalFromNullable(impl.verificationStateDescription())
      .map(value =>
        zio.aws.iot.model.primitives.VerificationStateDescription(value)
      )
    override val violationEventTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.violationEventTime())
      .map(value => zio.aws.iot.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.ViolationEvent
  ): zio.aws.iot.model.ViolationEvent.ReadOnly = new Wrapper(impl)
}

==> zio-aws-iot_3-5.17.104.11-sources.jar: zio/aws/iot/model/ViolationEvent.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.{
  DeviceDefenderThingName,
  ViolationId,
  Timestamp,
  SecurityProfileName,
  VerificationStateDescription
}
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters.*
final case class ViolationEvent(
    violationId: Option[ViolationId] = None,
    thingName: Option[DeviceDefenderThingName] = None,
    securityProfileName: Option[SecurityProfileName] = None,
    behavior: Option[zio.aws.iot.model.Behavior] = None,
    metricValue: Option[zio.aws.iot.model.MetricValue] = None,
    violationEventAdditionalInfo: Option[
      zio.aws.iot.model.ViolationEventAdditionalInfo
    ] = None,
    violationEventType: Option[zio.aws.iot.model.ViolationEventType] = None,
    verificationState: Option[zio.aws.iot.model.VerificationState] = None,
    verificationStateDescription: Option[VerificationStateDescription] = None,
    violationEventTime: Option[Timestamp] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.ViolationEvent = {
    import ViolationEvent.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.ViolationEvent
      .builder()
      .optionallyWith(
        violationId.map(value => ViolationId.unwrap(value): java.lang.String)
      )(_.violationId)
      .optionallyWith(
        thingName.map(value =>
          DeviceDefenderThingName.unwrap(value): java.lang.String
        )
      )(_.thingName)
      .optionallyWith(
        securityProfileName.map(value =>
          SecurityProfileName.unwrap(value): java.lang.String
        )
      )(_.securityProfileName)
      .optionallyWith(behavior.map(value => value.buildAwsValue()))(_.behavior)
      .optionallyWith(metricValue.map(value => value.buildAwsValue()))(
        _.metricValue
      )
      .optionallyWith(
        violationEventAdditionalInfo.map(value => value.buildAwsValue())
      )(_.violationEventAdditionalInfo)
      .optionallyWith(violationEventType.map(value => value.unwrap))(
        _.violationEventType
      )
      .optionallyWith(verificationState.map(value => value.unwrap))(
        _.verificationState
      )
      .optionallyWith(
        verificationStateDescription.map(value =>
          VerificationStateDescription.unwrap(value): java.lang.String
        )
      )(_.verificationStateDescription)
      .optionallyWith(
        violationEventTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.violationEventTime)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.ViolationEvent.ReadOnly =
    zio.aws.iot.model.ViolationEvent.wrap(buildAwsValue())
}
object ViolationEvent {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.ViolationEvent
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.ViolationEvent =
      zio.aws.iot.model.ViolationEvent(
        violationId.map(value => value),
        thingName.map(value => value),
        securityProfileName.map(value => value),
        behavior.map(value => value.asEditable),
        metricValue.map(value => value.asEditable),
        violationEventAdditionalInfo.map(value => value.asEditable),
        violationEventType.map(value => value),
        verificationState.map(value => value),
        verificationStateDescription.map(value => value),
        violationEventTime.map(value => value)
      )
    def violationId: Option[ViolationId]
    def thingName: Option[DeviceDefenderThingName]
    def securityProfileName: Option[SecurityProfileName]
    def behavior: Option[zio.aws.iot.model.Behavior.ReadOnly]
    def metricValue: Option[zio.aws.iot.model.MetricValue.ReadOnly]
    def violationEventAdditionalInfo
        : Option[zio.aws.iot.model.ViolationEventAdditionalInfo.ReadOnly]
    def violationEventType: Option[zio.aws.iot.model.ViolationEventType]
    def verificationState: Option[zio.aws.iot.model.VerificationState]
    def verificationStateDescription: Option[VerificationStateDescription]
    def violationEventTime: Option[Timestamp]
    def getViolationId: ZIO[Any, AwsError, ViolationId] =
      AwsError.unwrapOptionField("violationId", violationId)
    def getThingName: ZIO[Any, AwsError, DeviceDefenderThingName] =
      AwsError.unwrapOptionField("thingName", thingName)
    def getSecurityProfileName: ZIO[Any, AwsError, SecurityProfileName] =
      AwsError.unwrapOptionField("securityProfileName", securityProfileName)
    def getBehavior: ZIO[Any, AwsError, zio.aws.iot.model.Behavior.ReadOnly] =
      AwsError.unwrapOptionField("behavior", behavior)
    def getMetricValue
        : ZIO[Any, AwsError, zio.aws.iot.model.MetricValue.ReadOnly] =
      AwsError.unwrapOptionField("metricValue", metricValue)
    def getViolationEventAdditionalInfo: ZIO[
      Any,
      AwsError,
      zio.aws.iot.model.ViolationEventAdditionalInfo.ReadOnly
    ] = AwsError.unwrapOptionField(
      "violationEventAdditionalInfo",
      violationEventAdditionalInfo
    )
    def getViolationEventType
        : ZIO[Any, AwsError, zio.aws.iot.model.ViolationEventType] =
      AwsError.unwrapOptionField("violationEventType", violationEventType)
    def getVerificationState
        : ZIO[Any, AwsError, zio.aws.iot.model.VerificationState] =
      AwsError.unwrapOptionField("verificationState", verificationState)
    def getVerificationStateDescription
        : ZIO[Any, AwsError, VerificationStateDescription] =
      AwsError.unwrapOptionField(
        "verificationStateDescription",
        verificationStateDescription
      )
    def getViolationEventTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("violationEventTime", violationEventTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.ViolationEvent
  ) extends zio.aws.iot.model.ViolationEvent.ReadOnly {
    override val violationId: Option[ViolationId] = scala
      .Option(impl.violationId())
      .map(value => zio.aws.iot.model.primitives.ViolationId(value))
    override val thingName: Option[DeviceDefenderThingName] = scala
      .Option(impl.thingName())
      .map(value => zio.aws.iot.model.primitives.DeviceDefenderThingName(value))
    override val securityProfileName: Option[SecurityProfileName] = scala
      .Option(impl.securityProfileName())
      .map(value => zio.aws.iot.model.primitives.SecurityProfileName(value))
    override val behavior: Option[zio.aws.iot.model.Behavior.ReadOnly] = scala
      .Option(impl.behavior())
      .map(value => zio.aws.iot.model.Behavior.wrap(value))
    override val metricValue: Option[zio.aws.iot.model.MetricValue.ReadOnly] =
      scala
        .Option(impl.metricValue())
        .map(value => zio.aws.iot.model.MetricValue.wrap(value))
    override val violationEventAdditionalInfo
        : Option[zio.aws.iot.model.ViolationEventAdditionalInfo.ReadOnly] =
      scala
        .Option(impl.violationEventAdditionalInfo())
        .map(value =>
          zio.aws.iot.model.ViolationEventAdditionalInfo.wrap(value)
        )
    override val violationEventType
        : Option[zio.aws.iot.model.ViolationEventType] = scala
      .Option(impl.violationEventType())
      .map(value => zio.aws.iot.model.ViolationEventType.wrap(value))
    override val verificationState
        : Option[zio.aws.iot.model.VerificationState] = scala
      .Option(impl.verificationState())
      .map(value => zio.aws.iot.model.VerificationState.wrap(value))
    override val verificationStateDescription
        : Option[VerificationStateDescription] = scala
      .Option(impl.verificationStateDescription())
      .map(value =>
        zio.aws.iot.model.primitives.VerificationStateDescription(value)
      )
    override val violationEventTime: Option[Timestamp] = scala
      .Option(impl.violationEventTime())
      .map(value => zio.aws.iot.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.ViolationEvent
  ): zio.aws.iot.model.ViolationEvent.ReadOnly = new Wrapper(impl)
}
